@@ -15,12 +15,39 @@ import time
 import collections
 import threading
 import json
+import warnings
 
 
 
+#------------------------------------------------------------------------------
+# Specific Message
+#------------------------------------------------------------------------------
+def DisplayMessage_Python3():
+    logger.error('  ERROR: You must use Python 3 to use this App')
+
+
 #---------------------------------------------------------------
 # Decorator
 #---------------------------------------------------------------
+def dec_TempSuppressWarnings(type = DeprecationWarning):
+    ''' This Decorator allows to avoid displaying Deprecation Warning
+    (or other warnings) for the time of the function
+    '''
+    def dec_decoratorinside(input_fct):
+        def wrap_modifiedFunction(*l_paramInput, **d_paramInput):
+            #------- Before Function Execution -------
+            with warnings.catch_warnings(record=True):
+                warnings.simplefilter("always")
+                # warnings.simplefilter("ignore")
+                #------- Function execution -------
+                launchFunction = input_fct(*l_paramInput, **d_paramInput)
+                #------- After Function Execution -------
+                warnings.resetwarnings()
+            #------- Return the Function at the end-------
+            return launchFunction
+        return wrap_modifiedFunction
+    return dec_decoratorinside
+
 def dec_singletonsClass(input_classe):
     '''
     Singeltons decorators: always use the first instance
